@@ -34,10 +34,12 @@ typedef struct
 {
 	/* Applet */
 	PanelApplet *applet;
-	GtkWidget   *fixed;
+	GtkWidget   *vbox;
 	GtkWidget   *hbox;
 	GtkWidget   *eyes[MAX_EYES];
 	guint        timeout_id;
+	gint pointer_last_x;
+	gint pointer_last_y;
 
 	/* Theme */
 	GdkPixbuf *eye_image;
